@@ -16,6 +16,7 @@ functions and methods.
 # will benefit from caching using :class:`joblib.Memory`.
 
 import time
+
 import numpy as np
 
 
@@ -36,20 +37,21 @@ start = time.time()
 data_trans = costly_compute(data)
 end = time.time()
 
-print('\nThe function took {:.2f} s to compute.'.format(end - start))
-print('\nThe transformed data are:\n {}'.format(data_trans))
+print("\nThe function took {:.2f} s to compute.".format(end - start))
+print("\nThe transformed data are:\n {}".format(data_trans))
 
 ###############################################################################
 # Caching the result of a function to avoid recomputing
 ###############################################################################
 #
-# If we need to call our function several time with the same input data, it is
+# If we need to call our function several times with the same input data, it is
 # beneficial to avoid recomputing the same results over and over since it is
 # expensive. :class:`joblib.Memory` enables to cache results from a function
 # into a specific location.
 
 from joblib import Memory
-location = './cachedir'
+
+location = "./cachedir"
 memory = Memory(location, verbose=0)
 
 
@@ -64,8 +66,8 @@ start = time.time()
 data_trans = costly_compute_cached(data)
 end = time.time()
 
-print('\nThe function took {:.2f} s to compute.'.format(end - start))
-print('\nThe transformed data are:\n {}'.format(data_trans))
+print("\nThe function took {:.2f} s to compute.".format(end - start))
+print("\nThe transformed data are:\n {}".format(data_trans))
 
 ###############################################################################
 # At the first call, the results will be cached. Therefore, the computation
@@ -76,8 +78,8 @@ start = time.time()
 data_trans = costly_compute_cached(data)
 end = time.time()
 
-print('\nThe function took {:.2f} s to compute.'.format(end - start))
-print('\nThe transformed data are:\n {}'.format(data_trans))
+print("\nThe function took {:.2f} s to compute.".format(end - start))
+print("\nThe transformed data are:\n {}".format(data_trans))
 
 ###############################################################################
 # At the second call, the computation time is largely reduced since the results
@@ -114,8 +116,8 @@ start = time.time()
 data_trans = transformer.transform(data)
 end = time.time()
 
-print('\nThe function took {:.2f} s to compute.'.format(end - start))
-print('\nThe transformed data are:\n {}'.format(data_trans))
+print("\nThe function took {:.2f} s to compute.".format(end - start))
+print("\nThe transformed data are:\n {}".format(data_trans))
 
 ###############################################################################
 
@@ -123,8 +125,8 @@ start = time.time()
 data_trans = transformer.transform(data)
 end = time.time()
 
-print('\nThe function took {:.2f} s to compute.'.format(end - start))
-print('\nThe transformed data are:\n {}'.format(data_trans))
+print("\nThe function took {:.2f} s to compute.".format(end - start))
+print("\nThe transformed data are:\n {}".format(data_trans))
 
 ###############################################################################
 # As expected, the second call to the ``transform`` method load the results
